
// MainFrm.cpp : implementation of the CMainFrame class
//

#include "stdafx.h"
#include "TeeTest.h"

#include "MainFrm.h"

#include "TeeChart\TeeChartDefines.h"
#include "TeeChart\canvas.h"
#include "TeeChart\series.h"
#include "TeeChart\zoom.h"
#include "TeeChart\scroll.h"
#include "TeeChart\environment.h"
#include "TeeChart\aspect.h"
#include "TeeChart\teegdiplus.h"

#define ID_CHART1		1000
#define ID_CHART2		2000

#define ID_TIMER		3000
#define ELAPSE_TIMER	100

#define SERIES_LENGTH	20

#ifdef _DEBUG
#define new DEBUG_NEW
#endif

// CMainFrame

IMPLEMENT_DYNAMIC(CMainFrame, CFrameWnd)

BEGIN_MESSAGE_MAP(CMainFrame, CFrameWnd)
	ON_WM_CREATE()
	ON_WM_DESTROY()
END_MESSAGE_MAP()

BEGIN_EVENTSINK_MAP(CMainFrame, CFrameWnd)
END_EVENTSINK_MAP()

static UINT indicators[] =
{
	ID_SEPARATOR,           // status line indicator
	ID_INDICATOR_CAPS,
	ID_INDICATOR_NUM,
	ID_INDICATOR_SCRL,
};

// CMainFrame construction/destruction

CMainFrame::CMainFrame() 
{
	// TODO: add member initialization code here
}

CMainFrame::~CMainFrame()
{
}

int CMainFrame::OnCreate(LPCREATESTRUCT lpCreateStruct)
{
	Gdiplus::GdiplusStartupInput gdiPlusStartupInput;
	Gdiplus::GdiplusStartup(&m_GdiPlusToken, &gdiPlusStartupInput, NULL);

	if (CFrameWnd::OnCreate(lpCreateStruct) == -1)
		return -1;

    CRect rect;
    GetClientRect(rect);

	CRect chart1Rect(rect);
	chart1Rect.DeflateRect(0, 0, rect.Width() / 2, 0);

	m_pChart1 = std::unique_ptr<CTChart>(new CTChart());
    if (!m_pChart1->Create("Chart 1", WS_CHILD|WS_VISIBLE, chart1Rect, this, ID_CHART1))
		return -1;
	try
	{
		m_pChart1->GetAspect().GetGDIPlus().SetActive(false);
		m_pChart1->GetAspect().GetGDIPlus().GDIPlusShutdown();
	}
	catch (CException* pE)
	{
		AfxMessageBox("Caught an exception when calling TeeChart GDIPlusShutdown() for chart 1.", MB_ICONERROR|MB_OK);
		return -1;
	}

	CRect chart2Rect(chart1Rect);
	chart2Rect.MoveToXY(rect.Width() / 2, 0);

	m_pChart2 = std::unique_ptr<CTChart>(new CTChart());
    if (!m_pChart2->Create("Chart 2", WS_CHILD|WS_VISIBLE, chart2Rect, this, ID_CHART2))
		return -1;
	try
	{
		m_pChart2->GetAspect().GetGDIPlus().SetActive(false);
		m_pChart2->GetAspect().GetGDIPlus().GDIPlusShutdown();
	}
	catch (CException* pE)
	{
		AfxMessageBox("Caught an exception when calling TeeChart GDIPlusShutdown() for chart 2.", MB_ICONERROR|MB_OK);
		return -1;
	}

	if (!m_wndStatusBar.Create(this))
	{
		TRACE0("Failed to create status bar\n");
		return -1;      // fail to create
	}
	m_wndStatusBar.SetIndicators(indicators, sizeof(indicators)/sizeof(UINT));

	long seriesIndex1 = m_pChart1->AddSeries(scFastLine);
	CSeries& series1 = m_pChart1->Series(seriesIndex1);
	series1.FillSampleValues(20);

	long seriesIndex2 = m_pChart2->AddSeries(scFastLine);
	CSeries& series2 = m_pChart2->Series(seriesIndex2);
	series2.FillSampleValues(30);

	m_pChart1->GetZoom().SetEnable(false);								// disable "default" zooming
	m_pChart1->GetScroll().SetEnable(pmNone);							// disable "default" scrolling
	m_pChart1->GetEnvironment().SetMouseWheelScroll(false);				// disable "mouse wheel" scrolling

	m_pChart2->GetZoom().SetEnable(false);								// disable "default" zooming
	m_pChart2->GetScroll().SetEnable(pmNone);							// disable "default" scrolling
	m_pChart2->GetEnvironment().SetMouseWheelScroll(false);				// disable "mouse wheel" scrolling

	return 0;
}

afx_msg void CMainFrame::OnDestroy()
{
	m_pChart1->RemoveAllSeries();
	m_pChart2->RemoveAllSeries();

	Gdiplus::GdiplusShutdown(m_GdiPlusToken);
}

BOOL CMainFrame::PreCreateWindow(CREATESTRUCT& cs)
{
	if( !CFrameWnd::PreCreateWindow(cs) )
		return FALSE;
	// TODO: Modify the Window class or styles here by modifying
	//  the CREATESTRUCT cs

	cs.dwExStyle &= ~WS_EX_CLIENTEDGE;
	cs.lpszClass = AfxRegisterWndClass(0);
	return TRUE;
}

// CMainFrame diagnostics

#ifdef _DEBUG
void CMainFrame::AssertValid() const
{
	CFrameWnd::AssertValid();
}

void CMainFrame::Dump(CDumpContext& dc) const
{
	CFrameWnd::Dump(dc);
}
#endif //_DEBUG


// CMainFrame message handlers

